<?php

/******
** Lizatom Framework Version
*************************************/
define('LIZATOM_VER', '2.0');

/******
** Theme init hook
*************************************/
function ltfw_theme_init(){
	do_action('ltfw_theme_init');
}

/******
** Admin init hook
*************************************/
function ltfw_admin_init(){
	do_action('ltfw_admin_init');
}

/******
** Initialization adds hooks to
** two places: theme and admin
*************************************/
function ltfw_init(){
	
	if( is_admin() ):
		add_action('after_setup_theme','ltfw_admin_init');
	else:
		add_action('after_setup_theme','ltfw_theme_init');
	endif;
}

add_action('after_setup_theme','ltfw_init',1);

/******
** Set up theme data
*************************************/
function ltfw_generate_theme_data(){
	
	$get_lizatom_theme = get_theme_data(TEMPLATEPATH .'/style.css');
	$theme_title = $get_lizatom_theme['Title'];
	$theme_shortname = strtolower(preg_replace('/ /', '_', $theme_title));
	$theme_version = $get_lizatom_theme['Version'];
	$theme_template = $get_lizatom_theme['Template'];
	define('LIZATOM_NAME', $theme_title);
	define('TEMPLATENAME', $theme_title);
	define('LIZATOM_SHORT_NAME', $theme_shortname);
	define('LIZATOM_THEME_VER', $theme_version);

	if( file_exists(TEMPLATEPATH.'/admin/admin.php') ):
		define( 'THEME_PATH' , TEMPLATEPATH );
		define( 'THEME_DIR' , get_bloginfo("template_directory") );
	elseif( file_exists(STYLESHEETPATH.'/admin/admin.php') ):
		define( 'THEME_PATH' , STYLESHEETPATH );
		define( 'THEME_DIR' , get_bloginfo("stylesheet_directory") );
	endif;
	
	// Detect child theme info
	if(STYLESHEETPATH != TEMPLATEPATH): 
	    $get_lizatom_theme = get_theme_data(STYLESHEETPATH .'/style.css');
	    $theme_title = $get_lizatom_theme['Title'];
	    $theme_shortname = strtolower(preg_replace('/ /', '_', $theme_title));
	    $theme_version = $get_lizatom_theme['Version'];
	    $theme_template = $get_lizatom_theme['Template'];
	    define('CHILD_NAME', $theme_title);
	    define('CHILD_SHORT_NAME', $theme_shortname);
	    define('CHILD_THEME_VER', $theme_version);
	    define('CHILD_PATH', STYLESHEETPATH);
	endif;

}

add_action('ltfw_admin_init','ltfw_generate_theme_data',1);
add_action('ltfw_theme_init','ltfw_generate_theme_data',1);

/******
** Upload error msg
*************************************/
function ltfw_upload_error(){

	$uploads_dir = wp_upload_dir();
	$error = $uploads_dir['error'];
	echo '<div id="message" class="error"><p>' . $error . '</p></div>';
	return false;
	
}

/******
** Upload folder permissions 
** error msg
*************************************/
function ltfw_permissions_error(){

	echo '<div id="message" class="error"><p>' . __('It looks like your uploads folder does not have proper permissions. Please set your uploads folder, typically located at [wp-install]/wp-content/uploads/, to 775 or greater.','ltfw') . '</p></div>';
	return false;
	
}

/******
** Upload folder created 
** success msg
*************************************/
function ltfw_uploads_folder_created(){

	$uploads_dir = wp_upload_dir();
	$base_upload_dir = $uploads_dir['basedir']."/ltfw"; 
	
	echo '<div id="message" class="update-nag">' . __('Lizatom Framework uploads folders created successfully! Your new folder is located at '.$base_upload_dir.'.','ltfw') . '</div>';
	return false;
	
}

/******
** Set the uploads directory 
** for media from themes
*************************************/
function ltfw_set_uploads_dir(){

	$uploads_dir = wp_upload_dir();
	
	if( $uploads_dir['error'] )
		add_action( 'admin_notices', 'ltfw_upload_error', 1, 1 );
	else{
	
		$base_upload_dir = $uploads_dir['basedir']."/ltfw";
		$base_upload_url = $uploads_dir['baseurl']."/ltfw";
	
		if( (!is_dir($base_upload_dir)) ){
		
			if( !is_writeable( $uploads_dir['basedir'] ) ) 
				add_action( 'admin_notices', 'ltfw_permissions_error', 1, 1 );
			else{
				$oldumask = umask(0);
				@mkdir($base_upload_dir, 0777);
				umask($oldumask);
				
				if( (is_writeable( $base_upload_dir )))
					add_action( 'admin_notices', 'ltfw_uploads_folder_created',1 , 1 );
				
			}
		}
	}
	
	if($base_upload_dir)
		define('UPFW_UPLOADS_DIR',$base_upload_dir, true);
	
	if($base_upload_url)
		define('UPFW_UPLOADS_URL',$base_upload_url, true);
        
}

add_action('ltfw_theme_init','ltfw_set_uploads_dir',2);
add_action('ltfw_admin_init','ltfw_set_uploads_dir',2);

/******
** Gentlemen, start your engines
*************************************/
function ltfw_engines_init(){
    global $lizatom_options;
	require_once('library/options/options.php');
	require_once('library/widgets/dashboard.php');
	
	if( !defined('DISABLE_LAYOUT_ENGINE') )
		require_once('library/engines/layout-engine.php');
	
	if( !defined('DISABLE_STYLE_ENGINE') )
		require_once('library/engines/style-engine.php');
	
	if( !defined('DISABLE_TYPOGRAPHY_ENGINE') )
		require_once('library/engines/typography-engine.php');
    
    if( !defined('DISABLE_CUFON_ENGINE') || $lizatom_options->cufon_disable == "no" )
		require_once('library/engines/cufon-engine.php');    
	
	if( !defined('DISABLE_SEO_ENGINE') )
		require_once('library/engines/seo-engine.php');
 	
	if(function_exists('ltfw_dbwidget_setup'))
            add_action('wp_dashboard_setup', 'ltfw_dbwidget_setup' );
	
        if(function_exists('default_theme_layouts'))
            add_action('init','default_theme_layouts',1);
            
            if(function_exists('default_theme_styles'))
            add_action('init','default_theme_styles',2);

}

add_action('ltfw_theme_init','ltfw_engines_init',10);
add_action('ltfw_admin_init','ltfw_engines_init',10);

/******
** Conditional to test if we're on
** an Lizatom Framework page
*************************************/
function is_lizatomthemes_page(){

    if(is_admin()):
        if(isset($_REQUEST['page']))$page = $_REQUEST['page'];
        if(!empty($page)):
            if( $page =='lizatomthemes' || $page=='lizatomthemes-buy' || $page =='lizatomthemes-docs' ):
                    return true;
            else:
                    return false;
            endif;
        endif;
    endif;
		
}

/******
** Add CSS and Javascript includes
*************************************/
function ltfw_queue_scripts_styles(){

	$lizatomthemes =  THEME_DIR.'/admin/';
    wp_enqueue_script('jquery');
    wp_enqueue_style('thickbox');
    wp_enqueue_script('media-upload','','','',false);
    wp_enqueue_script('thickbox','','','',false);
	
	wp_enqueue_style('lizatom_framework',$lizatomthemes."css/lizatom_framework.css");
	
	//Check if theme-options/style.css exists and load it
	if(file_exists(THEME_PATH ."/theme-options/style.css")):
		wp_enqueue_style('theme_options',THEME_DIR."/theme-options/style.css");
	endif;
    
    // cufon start
    wp_enqueue_script('cufon.yui',
		get_bloginfo('template_directory') . "/lib/js/cufon-yui.js");
    
    wp_enqueue_script('league.gothic.font',
		get_bloginfo('template_directory') . "/cufon/league_gothic_400.font.js");    
	//cufon end
    
	wp_enqueue_style('farbtastic');
	
	wp_enqueue_script('jquery.history',
		$lizatomthemes."js/jquery.history.js",
		array('jquery'));
	
	wp_enqueue_script('jquery.color',
		$lizatomthemes."js/jquery.color.js",
		array('jquery'));

	wp_enqueue_script('ajaxupload',
		$lizatomthemes."js/ajaxupload.js",
		array('jquery'));
    
    /*wp_enqueue_script('jquery.uniform', 
		get_bloginfo('template_directory') . "/lib/uniform/jquery.uniform.js", 
		array('jquery'));*/
	
	wp_enqueue_script('ltfw', 
		$lizatomthemes . "js/lizatom_framework.js", 
		array('farbtastic','jquery.history','ajaxupload'));
    
    /* For Typography Engine */
    wp_enqueue_script('jquery-ui-core');
    wp_enqueue_script('jquery-ui-widget');
    wp_enqueue_script('jquery-ui-mouse');
    wp_enqueue_script('jquery-ui-slider', get_bloginfo('template_directory').'/admin/js/jquery.ui.slider.js', array('jquery-ui-core', 'jquery-ui-widget', 'jquery-ui-mouse'));
    wp_enqueue_style('up-slider', get_bloginfo('template_directory').'/admin/css/ui-themes/flick/style.css');
    //wp_enqueue_style('uniform_css', get_bloginfo("stylesheet_directory") . "/lib/uniform/css/uniform.default.css");

$cufon_upload_dir = get_stylesheet_directory() . "/cufon";
$cufon_upload_url = get_bloginfo('template_directory') . "/cufon";

/*echo "cufon_upload_dir: " . $cufon_upload_dir;
echo "<br>";
echo "cufon_upload_url: " . $cufon_upload_url;*/

global $cufon_files_arr, $cufon_names_arr, $cufon_arr;
$array[] = $cufon_arr;
$array[] = $cufon_files_arr;
$array[] = $cufon_names_arr;

		foreach(glob($cufon_upload_dir."/*.js") as $font_file){
		  
			$file_content = file_get_contents($font_file);
			if(preg_match('/font-family":"(.*?)"/i',$file_content,$match)){
				$fonts[$match[1]] = basename($font_file);
			}
            $file_name = basename($font_file);
            $cufon_files_arr[] = $file_name;
            $cufon_names_arr[] = $match[1];
            wp_enqueue_script('cufon-font-'.$count, $cufon_upload_url.'/'.$file_name, array('cufon.yui'));
            $count++;
		}
//print_r($cufon_files_arr);
//print_r($cufon_names_arr);
/*$count = 0;
        foreach (glob($cufon_upload_dir. "/*.js") as $path_to_files)
         {
             $file_name = basename($path_to_files);             
             $cufon_files_arr[] = $file_name;              
             
             wp_enqueue_script('cufon-font-'.$count, $cufon_upload_url.'/'.$file_name, array('cufon.yui'));                            
  $count++;
 }*/
}

if( is_admin() && is_lizatomthemes_page() ):
	add_action('ltfw_theme_init','ltfw_queue_scripts_styles',40);
	add_action('ltfw_admin_init','ltfw_queue_scripts_styles',40);
endif;

/******
** let's call the scripts
** in the admin footer
*************************************/

function add_js_to_footer(){ ?>
    <script type="text/javascript">
     jQuery(document).ready(function(){   
         //jQuery(function(){ jQuery("select,input:checkbox,input:radio").uniform(); });        
               
           
<?php  $count = 0;
                    
        global $cufon_names_arr; 
        if($cufon_names_arr!=null) {  
        //echo "this is add_js_to_footer(); hook";           
        //print_r($cufon_names_arr);
        foreach ($cufon_names_arr as $value) {
           
                 echo " Cufon.replace('label#cufon-font-$count', {
                                        fontFamily: '$value',
                                    	color: '-linear-gradient(#FDFDFD, #C0C0C0)',
                                        textShadow: '2px 2px #000',
                                        fontSize: '30px'                   
                                        });
                                        
                        Cufon.replace('label#cufon-font-$count span.cufonpreview', {
                                        fontFamily: '$value',
                                    	color: '-linear-gradient(#FFFFFF, #00CCFF)',
                                        textShadow: '2px 2px #000',
                                        fontSize: '30px'                   
                                        });" ;
                        $count++;
                        
        } } ?> 
        
          
	}); 
    
Cufon.replace('h2.tight,h3,label', {
fontFamily: 'League Gothic',
color: '-linear-gradient(#FDFDFD, #C0C0C0)',
textShadow: '2px 2px #000',                   
});

Cufon.replace('#lizatom_docs h2', {
fontFamily: 'League Gothic',
fontSize: '30px',
color: '-linear-gradient(#01AFFF, #C0C0C0)',
textShadow: '2px 2px #DADADA',                   
});

Cufon.replace('#lizatom_docs h3', {
fontFamily: 'League Gothic',
fontSize: '24px',
color: '-linear-gradient(#000, #C0C0C0)',
textShadow: '1px 1px #DADADA',                   
});

    </script>
<?php }

if( is_admin()  && is_lizatomthemes_page() )
	add_action("admin_print_footer_scripts","add_js_to_footer");


/******
** Show gallery images
*************************************/
function show_gallery_images(){
	global $wpdb; 

	$theme = THEME_DIR;
	
	$path = UPFW_UPLOADS_DIR."/";
	$dir_handle = @opendir($path) or die("Unable to open folder. Please make sure your uploads folder exists and has permissions of 775 or greater.");
	
	while (false !== ($file = readdir($dir_handle))):
	
		if($file == "index.php") continue;
		if($file == ".") continue;
		if($file == "..") continue;
		if($file == "list.php") continue;
		if($file == "Thumbs.db") continue;
		$list .= '<a class="preview" href="'. UPFW_UPLOADS_URL . "/". $file . '"><img src="' . UPFW_UPLOADS_URL . "/" . $file . '" /></a>';

	endwhile;
    
    $list .= '<div class="clear"></div>';
    
	echo $list;
	
	closedir($dir_handle);
	die();

}

add_action('wp_ajax_show_gallery_images','show_gallery_images');

/******
** Create Framework Options Pages
*************************************/
function ltfw_create_options_tabs(){

	// Discover Options Files and Create Tabs Array
	if( is_admin() ):
	    $path = THEME_PATH."/theme-options/";
	    $directory = @opendir($path) or wp_die("Cannot open theme-options folder in the ".LIZATOM_NAME." folder.");
	    while (false !== ($file = readdir($directory))) {
			if(!preg_match('/_/', $file)) continue;
			if(preg_match('/_notes/', $file)) continue;
			if(preg_match('/.DS/', $file)) continue;
	        
	        //Take the extension off
	        $file = explode('.php', $file);
	        
	        //Separate the ordinal
	        $file = explode('_', $file[0]);
	        $order = $file[1];
	        //Define the shortname
	        $shortname = $file[0];
	        
	        //Define the title
	        $file = explode('-', $shortname);
	        $title = '';
	        foreach ($file as $part):
	            $title .= $part." ";
	        endforeach;
	        $title = ucwords($title);
	        
	        //Add tab to array
	        global $lizatom_tabs;
	        $lizatom_tabs[$order] =  array(trim($title) => $shortname);
	        $title = '';
	    }
	    closedir($directory);
	    
	    //Sort tab order
	    global $lizatom_tabs;
	    ksort($lizatom_tabs);
	endif;

}

add_action('ltfw_admin_init','ltfw_create_options_tabs',50);

/******
** Install default theme options
** if not already set
*************************************/
function ltfw_set_defaults(){

	if( !get_option('lizatom_themes_'.LIZATOM_SHORT_NAME) && $_GET['page']!="lizatomthemes" ):
	
		//Redirect to options page where defaults will automatically be set
		header('Location: '.get_bloginfo('url').'/wp-admin/admin.php?page=lizatomthemes');
		exit;
	
	endif;

}

add_action('ltfw_theme_activation', 'ltfw_set_defaults',2);

/******
** Set up global theme options
*************************************/
function ltfw_setup_theme_options(){

	$lizatom_options_db = get_option('lizatom_themes_'.LIZATOM_SHORT_NAME);
			
	global $lizatom_options;
		
	//Check if options are stored properly
	if( isset($lizatom_options_db) && is_array($lizatom_options_db) ):
		
	    //Check array to an object
	    foreach ($lizatom_options_db as $k => $v) {
			$lizatom_options -> {$k} = $v;
	    }
	
	else:
	
		do_action('ltfw_theme_activation');
	
	endif;

}

add_action('ltfw_theme_init','ltfw_setup_theme_options',100);
add_action('ltfw_admin_init','ltfw_setup_theme_options',100);

/******
** Bootstrap static framework pages
*************************************/
function lizatomthemes_admin_home() {require_once('home.php');}
function lizatomthemes_admin_docs(){require_once('docs.php');}
function lizatomthemes_admin_buy(){require_once('buy.php');}
function lizatomthemes_admin_import_export(){require_once('import-export.php');}

/******
** Activate Lizatom Framework admin
*************************************/
function ltfw_lizatomthemes_admin() {

    $name = __('Theme Options','ltfw');

	$theme_options_icon = apply_filters('theme_options_icon',THEME_DIR.'/admin/images/ltfw_ico_lizatom_16x16.png');

    add_menu_page($name, $name, '10', 'lizatomthemes', 'lizatomthemes_admin_home', $theme_options_icon, 59);
  
	//Create tabbed pages from array
	global $lizatom_tabs;
	if( is_array( $lizatom_tabs ) ):
		foreach ($lizatom_tabs as $tab):
			foreach($tab as $title => $shortname):
				add_submenu_page('lizatomthemes', $title, $title, '10', 'lizatomthemes#/'.$shortname, 'lizatomthemes_admin_'.$shortname);
			endforeach;
		endforeach;
	endif;

	//Static subpages
	add_submenu_page('lizatomthemes', __('Import/Export','ltfw'), __('Import/Export','ltfw'), '10', 'lizatomthemes#/import-export', 'lizatomthemes_admin_import_export');
	add_submenu_page('lizatomthemes', __('Documentation','ltfw'), __('Documentation','ltfw'), '10', 'lizatomthemes-docs', 'lizatomthemes_admin_docs');
	//add_submenu_page('lizatomthemes', __('Buy Themes','ltfw'), __('Buy Themes','ltfw'), '10', 'lizatomthemes-buy', 'lizatomthemes_admin_buy');

}

add_action('admin_menu', 'ltfw_lizatomthemes_admin',2);

/******
** Find default options
*************************************/
function find_defaults($options){
    global $lizatom_defaults;
    print_r($options);
}

/******
** Render theme options
*************************************/
function render_options($options){
    
    foreach ($options as $value) {
        //Check if there are additional attributes
        if(is_array($value['attr'])):
            $i = $value['attr'];
            global $attr;
            //Convert array into a string
            foreach($i as $k => $v):
                $attr .= $k.'="'.$v.'" ';
            endforeach;
        endif;
        
        //Determine the type of input field
        switch ( $value['type'] ) {
            
            //Render Text Input
            case 'text': ltfw_text_field($value,$attr);
            break;
            
            //Render Custom User Text Inputs
            case 'text_list': ltfw_text_list($value,$attr);
            break;
            
            //Render textarea options
            case 'textarea': ltfw_textarea($value,$attr);
            break;
            
            //Render select dropdowns
            case 'select': ltfw_select($value,$attr);
            break;
            
            //Render multple selects
            case 'multiple': ltfw_multiple($value,$attr);
            break;
        
            //Render checkboxes
            case 'checkbox': ltfw_checkbox($value,$attr);
            break;
            
            //Render radio
            case 'radio': ltfw_radio($value,$attr);
            break;
            
            //Render color picker
            case 'color': ltfw_color($value,$attr);
            break;
            
            //Render upload image
            case 'image': ltfw_image($value,$attr);
            break;
            
            //Render category dropdown
            case 'category': ltfw_category($value,$attr);
            break;
            
            //Render categories multiple select
            case 'categories': ltfw_categories($value,$attr);
            break;
            
            //Render page dropdown
            case 'page': ltfw_page($value,$attr);
            break;
            
            //Render pages muliple select
            case 'pages': ltfw_pages($value,$attr);
            break;
        
            //Render Form Button
            case 'submit': ltfw_submit($value,$attr);
            break;

            //Render taxonomy multiple select
            case 'taxonomy': ltfw_taxonomy($value,$attr);
            break;

            //Render Typography Selector
            case 'typography': ltfw_typography($value,$attr);
            break;

            //Render Style Selector
            case 'styles': ltfw_style($value,$attr);
            break;
            
            //Render Form Button
            case 'button': ltfw_button($value,$attr);
            break;

			//Render Text Input
            case 'divider': ltfw_divider($value,$attr);
            break;
                    
            //Render Layouts
            case 'layouts': ltfw_layouts($value,$attr);
            break;
            
            //Render select cufon
            case 'select_cufon': ltfw_select_cufon($value,$attr);
            break;
            
            //Render checkbox cufon
            case 'checkbox_cufon': ltfw_checkbox_cufon($value,$attr);
            break;
            
            //Render sidebar
            case 'sidebar': ltfw_sidebar($value,$attr);
            break;
            
            //Render sidebar delete
            case 'sidebar_delete': ltfw_sidebar_delete($value,$attr);
            break;            
        
            default:
            break;
        }
        $attr = '';
    }
}

if(is_admin() && is_lizatomthemes_page()) add_action('ltfw_admin_init','ltfw_save_options',3);

function ltfw_save_options(){

    /* ----------------------- Form Security Check -------------------------- */
    if(isset($_POST['_wpnonce'])):
        //Check if submitted from this domain
        check_admin_referer();
        
        //Verify Form Nonce
        if (!wp_verify_nonce($_POST['_wpnonce'], 'save_lizatomthemes') ) 
            wp_die('Security exception detected, please try again.');
            exit;
    endif;

    /* ------------------Import/Export Functions ----------------------- */
    //Restore Previous Options
    global $export_message;
    if(isset($_POST['lizatom_restore'])):
        $current = get_option('lizatom_themes_'.LIZATOM_SHORT_NAME);
        $backup = get_option('lizatom_themes_'.LIZATOM_SHORT_NAME.'_backup');
        update_option('lizatom_themes_'.LIZATOM_SHORT_NAME.'_backup', $current);
        update_option('lizatom_themes_'.LIZATOM_SHORT_NAME, $backup);
        $export_message = "<p class='import'>" . __("Everything's back to normal now!","ltfw") . "</p>";
    endif;
    
    //Restore Defaults

    if(isset($_POST['lizatom_defaults'])):
        $current = get_option('lizatom_themes_'.LIZATOM_SHORT_NAME);
        update_option('lizatom_themes_'.LIZATOM_SHORT_NAME.'_backup', $current);
        delete_option('lizatom_themes_'.LIZATOM_SHORT_NAME);
        $export_message = "<p class='import'>" . __("Default options restored!","ltfw") . "<span><form method='post' action=''><input class='lizatom_restore' type='submit' name='lizatom_restore' value='" . __("Click Here to Undo","ltfw") . "'></form></span></p>";
    endif;

    /* ------------------------- Import Options Code ------------------------------- */
    if(isset($_POST['lizatom_import']) && isset($_POST['lizatom_import_code'])):
        $import = $_POST['lizatom_import_code'];
        $import = base64_decode($import);
        $import = explode('~~', $import);
        
        //Check if code is legitimate
        if(count($import) == 2):
            $option_name = $import[0];
            $options = explode('||', $import[1]);
    
            foreach ($options as $option):
                $option = explode('|', $option);
                global $new_options;
                $new_options[$option[0]] = preg_replace('/"/', '\'', stripslashes($option[1]));
            endforeach;
            $current_option = get_option($option_name);
            update_option($option_name.'_backup', $current_option);
            update_option($option_name, $new_options);
            $export_message = "<p class='import'>" . __("Options Code Import Successful!","ltfw") . "<span><form method='post' action=''><input class='lizatom_restore' type='submit' name='lizatom_restore' value='" . __("Click Here to Undo","ltfw") . "'></form></span></p>";
        else:
            $export_message = "<p class='import'>" . __("Oops! Something went wrong. <span>Try pasting your import code again.</span>","ltfw") . "</p>";
        endif;

    endif;

    /* ------------------------- Save Theme Options ------------------------------- */
    if(isset($_POST['lizatom_save'])):
    
            $posts = $_POST;
            foreach($posts as $k => $v):
                //Check if option is array (mulitple selects)
                if(is_array($v)):
                    //Check if array is empty
                    $check = 0;
                    foreach($v as $key => $value):    
                        if($value != ''):
                            $check++;
                        endif;
                    endforeach;
                    //If array is not empty
                    if($check > 0  ):
                        //Remove empty array elements
                        $post[$k] = array_filter($v);
                    else:
                        $post[$k] = '';
                    endif;
                    $check = 0;
                else:
                    //Remove slashes
                    $post[$k] = preg_replace('/"/', '\'', stripslashes($v));
                endif;
            endforeach;
            //Add options array to wp_options table
            update_option('lizatom_themes_'.LIZATOM_SHORT_NAME, $post);
            
            // write piecemaker xml
    //write_piecemaker();
        endif;
    
    /* ---------------------- Default Options Functions  ----------------- */
    global $default_check;
    global $default_options;
    
    $option_check = get_option('lizatom_themes_'.LIZATOM_SHORT_NAME);	
    if($option_check):
        $default_check = true;
    else:
        $default_check = false;
    endif;
    
    

}

/******
** Remove Ugly First Link in 
** WP Sidebar Menu
*************************************/

function remove_ugly_first_link(){ ?>
    <script type="text/javascript">
	jQuery(document).ready(function(){
	    jQuery('li#toplevel_page_lizatomthemes li.wp-first-item').remove();
	});
    </script>
<?php }

if( is_admin() )
	add_action("admin_head","remove_ugly_first_link");   
   

/******
** RSS URL: rss('return') will return 
** the value and not echo it.
*************************************/
function ltfw_rss($i = ''){
    global $lizatom_options;
    if($lizatom_options->feedburner):
        $rss = "http://feeds.feedburner.com/".$lizatom_options->feedburner;
    else:
        $rss = get_bloginfo_rss('rss2_url');
    endif;
    if($i == 'return'): return $rss; else: echo $rss; endif;
}

/******
** RSS Subscribe URL: rss_email('return') 
** will return the value and not echo it.
*************************************/
function ltfw_rss_email($i = ''){
    global $lizatom_options;
    if($lizatom_options->feedburner):
        $rssemail = "http://www.feedburner.com/fb/a/emailverifySubmit?feedId=" . $lizatom_options->feedburner;
    else:
        $rssemail = "#";
    endif;
    if($i == 'return'): return $rssemail; else: echo $rssemail; endif;
}

/******
** Admin header hook
*************************************/
function ltfw_admin_header(){
	do_action('ltfw_admin_header');
}

/******
** Open admin header
*************************************/
function ltfw_admin_header_open(){ ?>
		<div id="lizatom_header" class="polish"><?php
}

add_action('ltfw_admin_header','ltfw_admin_header_open',1);

/******
** Set admin header title
*************************************/
function ltfw_admin_header_title(){ ?>
			<div id="icon-ltfw" class="icon32 icon32-ltfw"></div>
            <h2><?php _e("Theme Options","ltfw"); ?></h2> <?php
}

//add_action('ltfw_admin_header','ltfw_admin_header_title',100);

/******
** Create admin header links
*************************************/
function ltfw_admin_header_links(){ ?>
			<ul id="lizatom_topnav">
				<?php do_action('ltfw_admin_header_links'); ?>
			</ul><!-- /#lizatom_topnav --><?php
}

add_action('ltfw_admin_header','ltfw_admin_header_links',50);

/******
** Close admin header
*************************************/
function ltfw_admin_header_close(){ ?>

			<div class="clear"></div>
		
		</div><!-- /#lizatom_header --><?php

}

add_action('ltfw_admin_header','ltfw_admin_header_close',500);

/******
** Add default header links
*************************************/
function ltfw_default_header_links(){ ?>

				<!--
<li class="support"><a href="http://lizatom.com/forum/"><?php _e("Support","ltfw"); ?></a></li>
-->
				<li class="documentation"><a href="<?php echo get_admin_url(); ?>admin.php?page=lizatomthemes-docs"><?php _e("Theme Documentation","ltfw"); ?></a></li>
				<!--
<li class="buy-themes"><a href="<?php echo get_admin_url(); ?>admin.php?page=lizatomthemes-buy"><?php _e("Buy Themes","ltfw"); ?></a></li>
--> <?php	

}

add_action('ltfw_admin_header_links','ltfw_default_header_links');

/*tabs*/
add_filter('media_upload_tabs','remove_medialibrary_tabs', 99);
function remove_medialibrary_tabs($tabs) {
    if ($post_id = (isset($_REQUEST['post_id']) ? $_REQUEST['post_id'] : false)) {
        if (count(get_posts("post_type=attachment&post_parent={$post_id}"))>0) {
            // MY QUESTION
        }
    }

    unset($tabs['type_url']);
    unset($tabs['library']);

    return $tabs;
}