<?php
/**
 * Template: functions.php
 *
 * @package Magdala
 * @subpackage Functions
 */

define( 'THEME_NAME', 'Magdala' );

define( 'THEMEDIR',  get_bloginfo('template_directory') ); 
define( 'THEMELIB',  THEMEDIR . '/lib' );
define( 'THEMECSS',  THEMELIB . '/css' );
define( 'THEMEJS',   THEMELIB . '/js' );
define( 'THEMEFUNC', THEMELIB . '/func' );

require_once (TEMPLATEPATH . '/lib/func/utils.php');
require_once (TEMPLATEPATH . '/lib/func/breadcrumbs.php');
require_once (TEMPLATEPATH . '/lib/func/thumbnail.php');
require_once (TEMPLATEPATH . '/lib/func/plugin-fold-page-list.php');
require_once (TEMPLATEPATH . '/lib/func/pagination.php');
require_once (TEMPLATEPATH . '/lib/shortcodes/shortcodes-ultimate.php');

require_once (TEMPLATEPATH . '/sidebar.php');
require_once (TEMPLATEPATH . '/sidebar-2.php');
require_once (TEMPLATEPATH . '/lizatom-comments.php');
require_once (TEMPLATEPATH . '/lizatom-loop-before.php');
require_once (TEMPLATEPATH . '/lizatom-article.php');
require_once (TEMPLATEPATH . '/lizatom-navpages.php');
require_once (TEMPLATEPATH . '/lizatom-not-found.php');

// Load Options panel
require_once('admin/admin.php');

/** ======================================================================================
 *  
 * add_action()                                                               add_action()
 * 
 * ====================================================================================== */

// Allow Shortcodes in Sidebar Widgets
add_filter('widget_text', 'do_shortcode');
// disable admin bar
show_admin_bar(false); 

//images
/*
update_option('thumbnail_size_w', 250);
update_option('thumbnail_size_h', 130);
add_image_size( 'feat-mini', 40, 40, true );
add_image_size( 'feat-medium', 130, 130, true );
add_image_size( 'feat-large', 630, 300, true );
*/


add_action('lizatom_loop_before', 'lizatom_loop_before_func');
add_action('lizatom_entry_top', 'lizatom_entry_top_func');
add_action('lizatom_entry', 'lizatom_entry_func');
add_action('lizatom_entry_bottom', 'lizatom_entry_bottom_func');
add_action('lizatom_sidebar', 'lizatom_sidebar_func');
//add_action('lizatom_sidebar_2', 'lizatom_sidebar_2_func');

//post thumbnails
add_theme_support( 'post-thumbnails' );
set_post_thumbnail_size( 100,100 );
//add_image_size( 'thumb2', 200, 200 );

//change bg in appearance->background
//add_custom_background();

//register custom menus. Customize them in appearance->menus
add_action( 'init', 'register_my_menus' );

add_action('wp_print_scripts', 'lizatom_load_js');
add_action('wp_print_styles', 'lizatom_load_styles');

/*add_action('wp_head', 'lizatom_load_superfishstyle');
add_action('wp_print_scripts', 'lizatom_load_superfish');*/

/** ======================================================================================
 * 
 * register widgets                                                       register widgets
 * 
 * ====================================================================================== */
 
if (function_exists('register_sidebar')) {
    register_sidebar(array(
    'before_widget' => '<div id="%1$s" class="%2$s widget">',    
    'before_title' => '<h3 class="widgettitle">',
    'after_title' => '</h3>',
    'after_widget' => '</div>',
    'name' => 'Sidebar 1'));
    register_sidebar(array(
    'before_widget' => '<div id="%1$s" class="%2$s widget">',    
    'before_title' => '<h3 class="widgettitle">',
    'after_title' => '</h3>',
    'after_widget' => '</div>',
    'name' => 'Header ad'));
    /* ---------------------------------------------------------------------------	if you need more widgets */
    register_sidebars(3, array(
    'before_widget' => '<div id="%1$s" class="%2$s widget">',
    'after_widget' => '</div>',
    'before_title' => '<h3 class="widgettitle">',
    'after_title' => '</h3>',
    'name' => 'Footer %d'
    ));
   
}

/** ======================================================================================
 * 
 * action hooks                                                               action hooks
 * 
 * ====================================================================================== */
//init
function lizatom_init() {
		do_action('lizatom_init');
}

//sidebar
if(!is_attachment()) add_action('lizatom_sidebar', 'lizatom_sidebar_func');
function lizatom_sidebar() {
		if(!wp_attachment_is_image()) do_action('lizatom_sidebar');
}

//sidebar-2
function lizatom_sidebar_2() {
		do_action('lizatom_sidebar_2');
}

//loop before
function lizatom_loop_before() {
		do_action('lizatom_loop_before');
}

//article-top
function lizatom_entry_top() {
		do_action('lizatom_entry_top');
}

//article-entry
function lizatom_entry() {
		do_action('lizatom_entry');
}

//article bottom
function lizatom_entry_bottom() {
		do_action('lizatom_entry_bottom');
}

//navpages
function lizatom_navpages() {
		do_action('lizatom_navpages');
}

//not found
function lizatom_not_found() {
		do_action('lizatom_not_found');
}
/** ======================================================================================
 * 
 * load CSS styles                                                         load CSS styles
 * 
 * ====================================================================================== */
 
/**
 * lizatom_load_styles()
 * 
 * load CSS styles
 * 
 * @since WP-HTML 0.9
 */
function lizatom_load_styles()
{
    if (!is_admin()) {        
        wp_enqueue_style('lizatom_reset_css', THEMECSS . '/reset.css');         
        wp_enqueue_style('lizatom_style_css', THEMEDIR . '/style.css');
        wp_enqueue_style('lizatom_superfish_css', THEMECSS . '/superfish.css');
        wp_enqueue_style('lizatom_superfish2_css', THEMECSS . '/superfish2.css');
        wp_enqueue_style('lizatom_comments_css', THEMECSS . '/comments.css');        
        wp_enqueue_style('lizatom_uniform_css', THEMELIB . '/uniform/css/uniform.default.css');               
        wp_enqueue_style('lizatom_tabs_css', THEMECSS . '/tabs.css');       
        wp_enqueue_style('lizatom_slideshow_css', THEMECSS . '/slideshow.css');        
    } 
}

/** ======================================================================================
 * 
 * load scripts                                                               load scripts 
 * 
 * ====================================================================================== */

/**
 * lizatom_load_js
 * 
 * load javascript
 * 
 * @since WP-HTML 0.9
 */
 
function lizatom_load_js()
{
    global $lizatom_options;
    
    if (!is_admin()) {
        // jquery
        wp_deregister_script( 'jquery' );
        wp_register_script( 'jquery', THEMEJS . '/jquery-1.5.1.js', '', '', false );
        wp_enqueue_script('jquery');        
        // easing
        wp_enqueue_script('lizatom_easing_js', THEMEJS . '/jquery.easing.1.3.js', array('jquery'), '', true);
        // news previewer
        wp_enqueue_script('lizatom_newspreviewer_js', THEMEJS . '/news-previewer.js', array('jquery','lizatom_easing_js'), '', true);
        // sizzle
        //wp_enqueue_script('lizatom_sizzle_js', THEMEJS . '/sizzle.js', array('jquery'), '', true);
        // contact form widget
        wp_enqueue_script('lizatom_contactform_widget_js', THEMEJS . '/widget-contact-form.js', array('jquery'), '', true);
        // columnizer
        //wp_enqueue_script('lizatom_columnizer_js', THEMEJS . '/autocolumn.min.js', array('jquery'), '', true);
        // uniform
        //wp_enqueue_script('lizatom_uniform_js', THEMELIB . '/uniform/jquery.uniform.min.js', array('jquery'), '', true);
        // tabs
        //wp_enqueue_script('lizatom_tabs_js', THEMEJS . '/tabs.js', array('jquery'), '', true);
        // cufon
        if($lizatom_options->cufon_disable=="no")
        wp_enqueue_script('cufon-yui', THEMEJS . '/cufon-yui.js', '', '', true);
        //wp_enqueue_script('lizatom_load-font_js', THEMEJS . '/bebas_400.font.js', '', '', true);
        // superfish
        wp_enqueue_script('lizatom_hoverintent_js', THEMEJS . '/hoverIntent.js', array('jquery'), '', true);
        wp_enqueue_script('lizatom_superfish_js', THEMEJS . '/superfish.js', array('jquery', 'lizatom_hoverintent_js'), '', true);
        // filterable
        //wp_enqueue_script('lizatom_filterable_js', THEMEJS . '/filterable.js', array('jquery'), '', true);
        // quicksand
        wp_enqueue_script('lizatom_quicksand_js', THEMEJS . '/jquery.quicksand.js', array('jquery'), '', true);
        // jcycle
        wp_enqueue_script('jquery=cycle',
            THEMEJS . '/jquery.cycle.all.2.73.js', array('jquery'), '', true);
            
        //cufon
        if($lizatom_options->cufon_disable=="no"){		
            foreach($lizatom_options->enable_cufon_fonts as $k=>$v) {
            wp_enqueue_script( '$cufon-font-'.$k, THEMEDIR .'/cufon/' . $v, array('jquery','cufon-yui'));                                            }
           
		}
            
        // custom
        wp_enqueue_script('lizatom_custom_js', THEMEJS . '/lizatom-custom.js', array ('jquery'), '1.0', true);
        }
}

function my_admin_scripts() {
wp_enqueue_script('media-upload');
wp_enqueue_script('thickbox');
wp_register_script('my-upload', THEMEDIR.'/admin/slidermanager/js/my-script.js', array('jquery','media-upload','thickbox'));
wp_enqueue_script('my-upload');
}

function my_admin_styles() {
wp_enqueue_style('thickbox');
}

if (isset($_GET['page']) && $_GET['page'] == 'slidermanager') {
//add_action('admin_print_scripts', 'my_admin_scripts');
//add_action('admin_print_styles', 'my_admin_styles');
}

/**
 * register_my_menus 
 * 
 * register custom menus
 * 
 * @since WP-HTML 0.9
 */

function register_my_menus()
{
    register_nav_menus(array('header-menu' => __('Header Menu')));
    register_nav_menus(array('header-menu2' => __('Header Menu2')));
    register_nav_menus(array('footer-menu' => __('Footer Menu')));
}

/*widgets related stuff*/

function lizatom_nospam( $email, $filterLevel = 'normal' ) {
	$email = strrev( $email );
	$email = preg_replace( '[@]', '//', $email );
	$email = preg_replace( '[\.]', '/', $email );

	if( $filterLevel == 'low' ) 	{
		$email = strrev( $email );
	}
	
	return $email;
}

add_action( 'widgets_init', 'lizatom_widgets' );

function lizatom_widgets() {
	# Load each widget file.
	require_once( TEMPLATEPATH . '/lib/widgets/widget-flickr.php' );
	require_once( TEMPLATEPATH . '/lib/widgets/widget-subnav.php' );
	require_once( TEMPLATEPATH . '/lib/widgets/widget-popular.php' );
	require_once( TEMPLATEPATH . '/lib/widgets/widget-recent.php' );
	require_once( TEMPLATEPATH . '/lib/widgets/widget-contact.php' );
	require_once( TEMPLATEPATH . '/lib/widgets/widget-contact-form.php' );

	# Register each widget.
	register_widget( 'Lizatom_Flickr_Widget' );
	register_widget( 'Lizatom_SubNav_Widget' );	
	register_widget( 'Lizatom_PopularPost_Widget' );
	register_widget( 'Lizatom_RecentPost_Widget' );
	register_widget( 'Lizatom_Contact_Widget' );
	register_widget( 'LizatomContactForm' );
}


?>